diff --git a/polkadot/runtime/rococo/src/weights/polkadot_runtime_parachains_paras.rs b/polkadot/runtime/rococo/src/weights/polkadot_runtime_parachains_paras.rs
index f67329755c8790b2e15b578be6048026118a61d1..bc8c6d5c51b3e9f5f952e9db15ab89ad83d6d958 100644
--- a/polkadot/runtime/rococo/src/weights/polkadot_runtime_parachains_paras.rs
+++ b/polkadot/runtime/rococo/src/weights/polkadot_runtime_parachains_paras.rs
@@ -17,9 +17,9 @@
 //! Autogenerated weights for `polkadot_runtime_parachains::paras`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 32.0.0
-//! DATE: 2025-02-27, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2025-03-04, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `79347b363bdd`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! HOSTNAME: `299f3957073a`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
 //! WASM-EXECUTION: `Compiled`, CHAIN: `None`, DB CACHE: 1024
 
 // Executed Command:
@@ -68,11 +68,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `8309`
 		//  Estimated: `11774`
-		// Minimum execution time: 34_420_000 picoseconds.
-		Weight::from_parts(34_744_000, 0)
+		// Minimum execution time: 34_344_000 picoseconds.
+		Weight::from_parts(35_086_000, 0)
 			.saturating_add(Weight::from_parts(0, 11774))
-			// Standard Error: 135
-			.saturating_add(Weight::from_parts(13_652, 0).saturating_mul(c.into()))
+			// Standard Error: 101
+			.saturating_add(Weight::from_parts(10_734, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(6))
 	}
@@ -83,11 +83,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 7_120_000 picoseconds.
-		Weight::from_parts(7_308_000, 0)
+		// Minimum execution time: 7_032_000 picoseconds.
+		Weight::from_parts(7_232_000, 0)
 			.saturating_add(Weight::from_parts(0, 0))
-			// Standard Error: 41
-			.saturating_add(Weight::from_parts(4_583, 0).saturating_mul(s.into()))
+			// Standard Error: 31
+			.saturating_add(Weight::from_parts(3_618, 0).saturating_mul(s.into()))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
 	/// Storage: `Paras::MostRecentContext` (r:0 w:1)
@@ -96,8 +96,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 3_536_000 picoseconds.
-		Weight::from_parts(3_801_000, 0)
+		// Minimum execution time: 3_545_000 picoseconds.
+		Weight::from_parts(3_822_000, 0)
 			.saturating_add(Weight::from_parts(0, 0))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
@@ -124,11 +124,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `8452`
 		//  Estimated: `11917`
-		// Minimum execution time: 50_575_000 picoseconds.
-		Weight::from_parts(51_394_000, 0)
+		// Minimum execution time: 50_046_000 picoseconds.
+		Weight::from_parts(50_780_000, 0)
 			.saturating_add(Weight::from_parts(0, 11917))
-			// Standard Error: 131
-			.saturating_add(Weight::from_parts(13_681, 0).saturating_mul(c.into()))
+			// Standard Error: 101
+			.saturating_add(Weight::from_parts(10_685, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(8))
 			.saturating_add(T::DbWeight::get().writes(7))
 	}
@@ -147,11 +147,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `299`
 		//  Estimated: `3764`
-		// Minimum execution time: 18_610_000 picoseconds.
-		Weight::from_parts(19_386_000, 0)
+		// Minimum execution time: 18_737_000 picoseconds.
+		Weight::from_parts(18_995_000, 0)
 			.saturating_add(Weight::from_parts(0, 3764))
-			// Standard Error: 43
-			.saturating_add(Weight::from_parts(4_602, 0).saturating_mul(s.into()))
+			// Standard Error: 31
+			.saturating_add(Weight::from_parts(3_645, 0).saturating_mul(s.into()))
 			.saturating_add(T::DbWeight::get().reads(2))
 			.saturating_add(T::DbWeight::get().writes(3))
 	}
@@ -163,8 +163,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `4312`
 		//  Estimated: `7777`
-		// Minimum execution time: 21_417_000 picoseconds.
-		Weight::from_parts(21_849_000, 0)
+		// Minimum execution time: 21_058_000 picoseconds.
+		Weight::from_parts(21_657_000, 0)
 			.saturating_add(Weight::from_parts(0, 7777))
 			.saturating_add(T::DbWeight::get().reads(2))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -182,11 +182,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `683`
 		//  Estimated: `4148`
-		// Minimum execution time: 87_281_000 picoseconds.
-		Weight::from_parts(89_737_000, 0)
+		// Minimum execution time: 85_102_000 picoseconds.
+		Weight::from_parts(86_779_000, 0)
 			.saturating_add(Weight::from_parts(0, 4148))
-			// Standard Error: 126
-			.saturating_add(Weight::from_parts(12_980, 0).saturating_mul(c.into()))
+			// Standard Error: 96
+			.saturating_add(Weight::from_parts(10_226, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(3))
 	}
@@ -198,8 +198,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `28`
 		//  Estimated: `3493`
-		// Minimum execution time: 7_018_000 picoseconds.
-		Weight::from_parts(7_255_000, 0)
+		// Minimum execution time: 7_005_000 picoseconds.
+		Weight::from_parts(7_242_000, 0)
 			.saturating_add(Weight::from_parts(0, 3493))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -214,8 +214,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `26706`
 		//  Estimated: `30171`
-		// Minimum execution time: 107_361_000 picoseconds.
-		Weight::from_parts(112_503_000, 0)
+		// Minimum execution time: 114_183_000 picoseconds.
+		Weight::from_parts(117_660_000, 0)
 			.saturating_add(Weight::from_parts(0, 30171))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -236,8 +236,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `27360`
 		//  Estimated: `30825`
-		// Minimum execution time: 739_794_000 picoseconds.
-		Weight::from_parts(770_941_000, 0)
+		// Minimum execution time: 701_780_000 picoseconds.
+		Weight::from_parts(717_725_000, 0)
 			.saturating_add(Weight::from_parts(0, 30825))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(103))
@@ -252,8 +252,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `27338`
 		//  Estimated: `30803`
-		// Minimum execution time: 105_596_000 picoseconds.
-		Weight::from_parts(108_616_000, 0)
+		// Minimum execution time: 111_232_000 picoseconds.
+		Weight::from_parts(116_478_000, 0)
 			.saturating_add(Weight::from_parts(0, 30803))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -272,8 +272,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `26728`
 		//  Estimated: `30193`
-		// Minimum execution time: 602_259_000 picoseconds.
-		Weight::from_parts(619_727_000, 0)
+		// Minimum execution time: 566_791_000 picoseconds.
+		Weight::from_parts(588_058_000, 0)
 			.saturating_add(Weight::from_parts(0, 30193))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(3))
@@ -288,26 +288,25 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `26706`
 		//  Estimated: `30171`
-		// Minimum execution time: 100_521_000 picoseconds.
-		Weight::from_parts(107_587_000, 0)
+		// Minimum execution time: 106_546_000 picoseconds.
+		Weight::from_parts(112_236_000, 0)
 			.saturating_add(Weight::from_parts(0, 30171))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
-	/// Storage: `Paras::AuthorizedCodeHash` (r:1 w:1)
-	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
+	/// Storage: `Paras::AuthorizedCodeHash` (r:0 w:1)
+	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: None, `max_size`: None, mode: `Measured`)
 	fn authorize_force_set_current_code_hash() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `28`
-		//  Estimated: `1513`
-		// Minimum execution time: 10_250_000 picoseconds.
-		Weight::from_parts(10_652_000, 0)
-			.saturating_add(Weight::from_parts(0, 1513))
-			.saturating_add(T::DbWeight::get().reads(1))
+		//  Measured:  `0`
+		//  Estimated: `0`
+		// Minimum execution time: 8_217_000 picoseconds.
+		Weight::from_parts(8_415_000, 0)
+			.saturating_add(Weight::from_parts(0, 0))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
 	/// Storage: `Paras::AuthorizedCodeHash` (r:1 w:1)
-	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
+	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: None, `max_size`: None, mode: `Measured`)
 	/// Storage: `Paras::CodeByHashRefs` (r:1 w:1)
 	/// Proof: `Paras::CodeByHashRefs` (`max_values`: None, `max_size`: None, mode: `Measured`)
 	/// Storage: `Paras::CurrentCodeHash` (r:1 w:1)
@@ -317,13 +316,13 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 	/// The range of component `c` is `[9, 3145728]`.
 	fn apply_authorized_force_set_current_code(c: u32, ) -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `126`
-		//  Estimated: `3591`
-		// Minimum execution time: 27_575_000 picoseconds.
-		Weight::from_parts(28_535_000, 0)
-			.saturating_add(Weight::from_parts(0, 3591))
-			// Standard Error: 131
-			.saturating_add(Weight::from_parts(14_711, 0).saturating_mul(c.into()))
+		//  Measured:  `132`
+		//  Estimated: `3597`
+		// Minimum execution time: 29_238_000 picoseconds.
+		Weight::from_parts(29_741_000, 0)
+			.saturating_add(Weight::from_parts(0, 3597))
+			// Standard Error: 103
+			.saturating_add(Weight::from_parts(12_157, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(4))
 	}
diff --git a/polkadot/runtime/westend/src/weights/polkadot_runtime_parachains_paras.rs b/polkadot/runtime/westend/src/weights/polkadot_runtime_parachains_paras.rs
index 66ca0d2465cb9f216b5c391ad6958bf23609103c..a5fcf3b95f30303c55ccf03870390e0839f05ad2 100644
--- a/polkadot/runtime/westend/src/weights/polkadot_runtime_parachains_paras.rs
+++ b/polkadot/runtime/westend/src/weights/polkadot_runtime_parachains_paras.rs
@@ -17,9 +17,9 @@
 //! Autogenerated weights for `polkadot_runtime_parachains::paras`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 32.0.0
-//! DATE: 2025-02-27, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2025-03-04, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `79347b363bdd`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! HOSTNAME: `299f3957073a`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
 //! WASM-EXECUTION: `Compiled`, CHAIN: `None`, DB CACHE: 1024
 
 // Executed Command:
@@ -68,11 +68,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `8309`
 		//  Estimated: `11774`
-		// Minimum execution time: 36_848_000 picoseconds.
-		Weight::from_parts(38_037_000, 0)
+		// Minimum execution time: 38_137_000 picoseconds.
+		Weight::from_parts(38_981_000, 0)
 			.saturating_add(Weight::from_parts(0, 11774))
-			// Standard Error: 97
-			.saturating_add(Weight::from_parts(10_714, 0).saturating_mul(c.into()))
+			// Standard Error: 129
+			.saturating_add(Weight::from_parts(13_542, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(6))
 	}
@@ -83,11 +83,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 6_844_000 picoseconds.
-		Weight::from_parts(6_947_000, 0)
+		// Minimum execution time: 6_970_000 picoseconds.
+		Weight::from_parts(7_230_000, 0)
 			.saturating_add(Weight::from_parts(0, 0))
-			// Standard Error: 33
-			.saturating_add(Weight::from_parts(3_880, 0).saturating_mul(s.into()))
+			// Standard Error: 42
+			.saturating_add(Weight::from_parts(4_548, 0).saturating_mul(s.into()))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
 	/// Storage: `Paras::MostRecentContext` (r:0 w:1)
@@ -96,8 +96,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 3_468_000 picoseconds.
-		Weight::from_parts(3_708_000, 0)
+		// Minimum execution time: 3_539_000 picoseconds.
+		Weight::from_parts(3_836_000, 0)
 			.saturating_add(Weight::from_parts(0, 0))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
@@ -124,11 +124,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `8452`
 		//  Estimated: `11917`
-		// Minimum execution time: 51_536_000 picoseconds.
-		Weight::from_parts(52_781_000, 0)
+		// Minimum execution time: 52_993_000 picoseconds.
+		Weight::from_parts(53_656_000, 0)
 			.saturating_add(Weight::from_parts(0, 11917))
-			// Standard Error: 97
-			.saturating_add(Weight::from_parts(10_726, 0).saturating_mul(c.into()))
+			// Standard Error: 132
+			.saturating_add(Weight::from_parts(13_454, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(8))
 			.saturating_add(T::DbWeight::get().writes(7))
 	}
@@ -145,11 +145,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `268`
 		//  Estimated: `3733`
-		// Minimum execution time: 14_371_000 picoseconds.
-		Weight::from_parts(14_746_000, 0)
+		// Minimum execution time: 14_784_000 picoseconds.
+		Weight::from_parts(15_216_000, 0)
 			.saturating_add(Weight::from_parts(0, 3733))
-			// Standard Error: 32
-			.saturating_add(Weight::from_parts(3_910, 0).saturating_mul(s.into()))
+			// Standard Error: 42
+			.saturating_add(Weight::from_parts(4_570, 0).saturating_mul(s.into()))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(3))
 	}
@@ -161,8 +161,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `4312`
 		//  Estimated: `7777`
-		// Minimum execution time: 24_060_000 picoseconds.
-		Weight::from_parts(25_218_000, 0)
+		// Minimum execution time: 24_300_000 picoseconds.
+		Weight::from_parts(25_154_000, 0)
 			.saturating_add(Weight::from_parts(0, 7777))
 			.saturating_add(T::DbWeight::get().reads(2))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -180,11 +180,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `683`
 		//  Estimated: `4148`
-		// Minimum execution time: 87_440_000 picoseconds.
-		Weight::from_parts(89_866_000, 0)
+		// Minimum execution time: 91_676_000 picoseconds.
+		Weight::from_parts(93_066_000, 0)
 			.saturating_add(Weight::from_parts(0, 4148))
-			// Standard Error: 93
-			.saturating_add(Weight::from_parts(10_639, 0).saturating_mul(c.into()))
+			// Standard Error: 127
+			.saturating_add(Weight::from_parts(12_834, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(3))
 	}
@@ -196,8 +196,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `28`
 		//  Estimated: `3493`
-		// Minimum execution time: 6_893_000 picoseconds.
-		Weight::from_parts(7_154_000, 0)
+		// Minimum execution time: 6_886_000 picoseconds.
+		Weight::from_parts(7_123_000, 0)
 			.saturating_add(Weight::from_parts(0, 3493))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -212,8 +212,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `26706`
 		//  Estimated: `30171`
-		// Minimum execution time: 111_526_000 picoseconds.
-		Weight::from_parts(133_072_000, 0)
+		// Minimum execution time: 114_157_000 picoseconds.
+		Weight::from_parts(120_289_000, 0)
 			.saturating_add(Weight::from_parts(0, 30171))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -234,8 +234,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `27360`
 		//  Estimated: `30825`
-		// Minimum execution time: 740_026_000 picoseconds.
-		Weight::from_parts(776_301_000, 0)
+		// Minimum execution time: 727_795_000 picoseconds.
+		Weight::from_parts(754_623_000, 0)
 			.saturating_add(Weight::from_parts(0, 30825))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(103))
@@ -250,8 +250,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `27338`
 		//  Estimated: `30803`
-		// Minimum execution time: 109_240_000 picoseconds.
-		Weight::from_parts(129_275_000, 0)
+		// Minimum execution time: 110_002_000 picoseconds.
+		Weight::from_parts(117_296_000, 0)
 			.saturating_add(Weight::from_parts(0, 30803))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -270,8 +270,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `26728`
 		//  Estimated: `30193`
-		// Minimum execution time: 591_032_000 picoseconds.
-		Weight::from_parts(615_374_000, 0)
+		// Minimum execution time: 585_996_000 picoseconds.
+		Weight::from_parts(609_200_000, 0)
 			.saturating_add(Weight::from_parts(0, 30193))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(3))
@@ -286,26 +286,25 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `26706`
 		//  Estimated: `30171`
-		// Minimum execution time: 107_013_000 picoseconds.
-		Weight::from_parts(127_959_000, 0)
+		// Minimum execution time: 106_306_000 picoseconds.
+		Weight::from_parts(113_807_000, 0)
 			.saturating_add(Weight::from_parts(0, 30171))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
-	/// Storage: `Paras::AuthorizedCodeHash` (r:1 w:1)
-	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
+	/// Storage: `Paras::AuthorizedCodeHash` (r:0 w:1)
+	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: None, `max_size`: None, mode: `Measured`)
 	fn authorize_force_set_current_code_hash() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `28`
-		//  Estimated: `1513`
-		// Minimum execution time: 9_579_000 picoseconds.
-		Weight::from_parts(10_266_000, 0)
-			.saturating_add(Weight::from_parts(0, 1513))
-			.saturating_add(T::DbWeight::get().reads(1))
+		//  Measured:  `0`
+		//  Estimated: `0`
+		// Minimum execution time: 8_112_000 picoseconds.
+		Weight::from_parts(8_401_000, 0)
+			.saturating_add(Weight::from_parts(0, 0))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
 	/// Storage: `Paras::AuthorizedCodeHash` (r:1 w:1)
-	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
+	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: None, `max_size`: None, mode: `Measured`)
 	/// Storage: `Paras::CodeByHashRefs` (r:1 w:1)
 	/// Proof: `Paras::CodeByHashRefs` (`max_values`: None, `max_size`: None, mode: `Measured`)
 	/// Storage: `Paras::CurrentCodeHash` (r:1 w:1)
@@ -315,13 +314,13 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 	/// The range of component `c` is `[9, 3145728]`.
 	fn apply_authorized_force_set_current_code(c: u32, ) -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `126`
-		//  Estimated: `3591`
-		// Minimum execution time: 31_189_000 picoseconds.
-		Weight::from_parts(32_054_000, 0)
-			.saturating_add(Weight::from_parts(0, 3591))
-			// Standard Error: 102
-			.saturating_add(Weight::from_parts(12_396, 0).saturating_mul(c.into()))
+		//  Measured:  `132`
+		//  Estimated: `3597`
+		// Minimum execution time: 32_733_000 picoseconds.
+		Weight::from_parts(33_172_000, 0)
+			.saturating_add(Weight::from_parts(0, 3597))
+			// Standard Error: 133
+			.saturating_add(Weight::from_parts(14_731, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(4))
 	}